<?php
/**
 *
 * Plugin Name: WP Redirects - Contact Form 7
 * Description: This is custom redirection on successfull submission of contact form 7.
 * Version: 2.0
 * Author: Yudiz Solution Ltd.
 * Author URI: http://www.yudiz.com/
 *
 **/

/**
* Plugin path url
*/
define( 'YSPL_CF7R_PLUGIN', __FILE__ );

/**
* Plugin directory path
*/
define( 'YSPL_CF7R_PLUGIN_DIR', untrailingslashit( dirname( YSPL_CF7R_PLUGIN ) ) );

/**
* Include redirection table template
*/
require_once YSPL_CF7R_PLUGIN_DIR . ('/includes/templates/redirection_table.php');

/*  Check Contact Form 7 Plugin is activated    */
function yspl_cf7r_admin_notices() {
    // Verify that CF7 is active and updated to the required version (currently 3.9.0)
    if ( !is_plugin_active('contact-form-7/wp-contact-form-7.php') ) {
         echo __('<div class="error"><p>Please have Contact Form 7 activated to use contact form 7 redirections plugin.</p></div>');
    }
}
add_action( 'admin_notices', 'yspl_cf7r_admin_notices' );

/*********************************************/
/**  Start -- Include additional scripts */

/* Following script will be included for wp-admin */
function yspl_cf7r_load_admin_scripts() {
    wp_enqueue_script('script', plugin_dir_url( __FILE__ ).'includes/js/admin.js');
}
add_action('admin_enqueue_scripts', 'yspl_cf7r_load_admin_scripts');

/* Enqueue admin-ajax */
function yspl_cf7r_load_wp_scripts() {
    $nonce = wp_create_nonce( 'custom_redirect' );

    // Register & Enqueue custom.js that will use ajax
    wp_register_script( 'ajax-script', plugin_dir_url( __FILE__ ).'includes/js/custom.js') ;
    wp_enqueue_script( 'ajax-script');

    // Bind attributes needed for ajax
    $passedValues = array( 
                        "url" => admin_url(sanitize_file_name('admin-ajax.php')) , 
                        "action" => "yspl_cf7r_admin_scripts" , 
                        "nonce" => $nonce
                    );
    // Pass attributes object to ajax call 
    wp_localize_script( 'ajax-script', 'passed_object', $passedValues );
}
add_action('wp_enqueue_scripts', 'yspl_cf7r_load_wp_scripts');

// Register scripts to be enqueue with wp-admin ajax
add_action( 'wp_ajax_yspl_cf7r_admin_scripts', 'yspl_cf7r_admin_scripts' );
add_action( 'wp_ajax_nopriv_yspl_cf7r_admin_scripts', 'yspl_cf7r_admin_scripts' );

// Handle ajax call
function yspl_cf7r_admin_scripts(){
    check_ajax_referer( "custom_redirect" );
        $id = sanitize_text_field($_POST['id']);
    if(!empty($id)){
        $form_check = get_post_meta($id,"check_id",true);
        if(empty($form_check)){
            wp_send_json_success(array('empty'=>"true","url"=>""));
        }else{
            if($form_check == 1 ){
                $key = "succ_page_id";
                $form_url = get_permalink(get_post_meta($id,$key,true));
            }else{
                $key = "succ_page_url";                  
                $form_url = get_post_meta($id,$key,true);
            }  

            if(empty($form_url)){
                wp_send_json_success(array('empty'=>"true","url"=>""));   
            }else{
                wp_send_json_success(array('success'=>"true","url"=>$form_url));   
            }
        }
    }
}
/* End -- Include additional scripts  */
/*********************************************/

/*  Add new tab to "Edit Menu" of contact form  */
function yspl_cf7r_add_tab( $panels ) { 
	$panels["custom-redirect-settings"] = array("title"=>"Custom Redirections","callback"=>"yspl_cf7r_set_redirects");
    update_option( 'cf7r_tab', array_search("custom-redirect-settings",array_keys($panels)) );
    return $panels; 
}; 
add_filter( 'wpcf7_editor_panels', 'yspl_cf7r_add_tab' ); 

/*  Edit redirection tab view     */
function yspl_cf7r_set_redirects($post){

    wp_nonce_field( 'add_metabox', 'add_metabox_nonce' );

    $check_id = get_post_meta(absint($post->id()) ,"check_id",true);
    $succ_page_id = get_post_meta( absint($post->id()), 'succ_page_id', true );
    $succ_page_url = get_post_meta( absint($post->id()), 'succ_page_url', true );

    ?>
    <h3>Redirect Settings</h3>

    <!-- Radio button to select id or url  -->
    <input type="radio" name="type" value="1" <?php echo esc_attr($check_id==1)?"checked":""; ?>>Select from existing pages    
    <input type="radio" name="type" value="2"  <?php echo esc_attr($check_id==2)?"checked":""; ?>>Add Custom Url

    <!-- Custom url div -->
    <div class="select_url" hidden>
       <input type="text" name="url" value="<?php echo esc_url(($check_id==2)?$succ_page_url:""); ?>">        
    </div>

    <?php
    // The meta box content for page dropdown
    $options = array (
            'echo' => 0,
            'name' => 'succ_page_id', 
            'show_option_none' => '--', 
            'option_none_value' => '0',
            'selected' => $succ_page_id
        );

    ?>

    <!-- Custom Page div -->
    	<div class="select_page">Select a page.
    		<?php echo wp_dropdown_pages( $options )?>
		</div>
    <?php
}

/*********************************************/
// Store Success Page/URL Info  -- Save contact form
function yspl_cf7r_save_contact_form( $contact_form ) {
    $form_id = $contact_form->id();
    if ( !isset( $_POST ) || empty( $_POST ) || !isset( $_POST['type'] ) ) {
         wpcf7_enqueue_scripts();
        return true;
    }else{ 
        $type = sanitize_text_field($_POST['type']);
        if($type == 1){
            $meta_value = sanitize_text_field($_POST['succ_page_id']);
            
            update_post_meta( $form_id, 'succ_page_id', $meta_value );
            update_post_meta( $form_id, 'check_id', "1" ); 
        }
        if($type == 2){
            $meta_value = sanitize_text_field($_POST['url']);

            update_post_meta( $form_id, 'succ_page_url', $meta_value );
            update_post_meta( $form_id, 'check_id', "2" );
        }  
    }  
}
add_action( 'wpcf7_after_save', 'yspl_cf7r_save_contact_form' );

// Store Success Page Info  === END
/*********************************************/


/***************************************************
        ADD CUSTOM OPTION PAGE TO Contact form MENU
****************************************************/
// Create submenu page for contact form 7 menu
add_action('admin_menu', 'yspl_cf7r_create_menu');

function yspl_cf7r_create_menu() {

    $edit = add_submenu_page( 'wpcf7',
    __( 'Edit Contact Form', 'contact-form-7' ),
    __( 'Form Redirects', 'contact-form-7' ),
    'wpcf7_edit_contact_forms', 'wpcf7-redirects',
    'yspl_cf7r_redirect_page' );

    add_action( 'load-' . $edit, 'wpcf7_load_contact_form_admin' );
}

// Data to be shown in submenu page
function yspl_cf7r_redirect_page() {

    ob_start();
    $cf7rTable = new CF7_Redirection_Table();
    ?>
    <div class="wrap"><h2>Contact Forms Redirection Listing</h2>
        <?php
            $cf7rTable->prepare_items(); 
            $cf7rTable->display(); 
        ?>
    </div>
    <?php
    echo ob_get_clean();
}
